from setuptools import setup

setup(
    name='telegram_url_to_screenshot',
    version='1.1',
    packages=[''],
    url='https://github.com/m0nte-cr1st0/telegram-url-to-screenshot-bot',
    license='Apache 2.0',
    author='Dmitriy Dmytruk',
    author_email='dinamo.mutu111@gmail.com',
    description='Opens received url and makes screenshot'
)
